@@ -18,7 +18,12 @@ import aws_cdk.core._jsii
 import aws_cdk.region_info._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53-patterns", "1.48.0", __name__[0:-6], "aws-route53-patterns@1.48.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-route53-patterns",
+    "1.52.0",
+    __name__[0:-6],
+    "aws-route53-patterns@1.52.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
